# -*- coding: utf-8 -*-
import pytest

from nerval import evaluate

fake_annot_aligned = "Gérard de -N-erval was bo-rn in Paris in 1808 -."
fake_predict_aligned = "G*rard de *N*erval ----bo*rn in Paris in 1833 *."

# fmt: off
fake_annot_tags_aligned = [
    'PER', 'PER', 'PER', 'PER', 'PER', 'PER',
    'PER',
    'PER', 'PER',
    'PER',
    'PER', 'PER', 'PER', 'PER', 'PER', 'PER', 'PER', 'PER',
    'O',
    'O', 'O', 'O',
    'O',
    'O', 'O', 'O', 'O', 'O',
    'O',
    'O', 'O',
    'O',
    'LOC', 'LOC', 'LOC', 'LOC', 'LOC',
    'O',
    'O', 'O',
    'O',
    'DAT', 'DAT', 'DAT', 'DAT',
    'O',
    'O', 'O'
]

fake_predict_tags_aligned = [
    'PER', 'PER', 'PER', 'PER', 'PER', 'PER',
    'PER',
    'PER', 'PER',
    'PER',
    'PER', 'PER', 'PER', 'PER', 'PER', 'PER', 'PER', 'PER',
    'O',
    'O', 'O', 'O', 'O',
    'O', 'O', 'O', 'O', 'O',
    'O',
    'O', 'O',
    'O',
    '***', '***', '***', '***', '***',
    'O',
    'O', 'O',
    'O',
    'DAT', 'DAT', 'DAT', 'DAT',
    'O',
    'O', 'O'
]
# fmt: on

expected_matches = {"All": 1, "PER": 1, "LOC": 0, "DAT": 0}


@pytest.mark.parametrize(
    "test_input, expected",
    [
        (
            (
                fake_annot_aligned,
                fake_predict_aligned,
                fake_annot_tags_aligned,
                fake_predict_tags_aligned,
            ),
            expected_matches,
        )
    ],
)
def test_compute_matches(test_input, expected):
    assert evaluate.compute_matches(*test_input) == expected


def test_compute_matches_empty_entry():
    with pytest.raises(AssertionError):
        evaluate.compute_matches(None, None, None, None)
